Package 'rk.lookup'
| Title: |
An RKWard plugin for looking up values using the 'lookup'
package. Features a single interface for both Vector-based
lookup and Excel-style Vlookup. |
| Description: |
An RKWard plugin for looking up values using the 'lookup'
package. Features a single interface for both Vector-based
lookup and Excel-style Vlookup. |
| Authors: |
Alfonso Cano |
| Maintainer: |
Alfonso Cano <[email protected]> |
| License: |
GPL (>= 3) |
| Version: |
0.0.1 |
| Built: |
2026-06-04 10:07:25 UTC |
| Source: |
https://github.com/AlfCano/rk.lookup |
Help Index